package com.ruoyi.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.base.mapper.BaseCabinetInfoMapper;
import com.ruoyi.base.domain.BaseCabinetInfo;
import com.ruoyi.base.service.IBaseCabinetInfoService;

/**
 * 电柜信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-10-31
 */
@Service
public class BaseCabinetInfoServiceImpl implements IBaseCabinetInfoService 
{
    @Autowired
    private BaseCabinetInfoMapper baseCabinetInfoMapper;

    /**
     * 查询电柜信息
     * 
     * @param objId 电柜信息主键
     * @return 电柜信息
     */
    @Override
    public BaseCabinetInfo selectBaseCabinetInfoByObjId(Long objId)
    {
        return baseCabinetInfoMapper.selectBaseCabinetInfoByObjId(objId);
    }

    /**
     * 查询电柜信息列表
     * 
     * @param baseCabinetInfo 电柜信息
     * @return 电柜信息
     */
    @Override
    public List<BaseCabinetInfo> selectBaseCabinetInfoList(BaseCabinetInfo baseCabinetInfo)
    {
        return baseCabinetInfoMapper.selectBaseCabinetInfoList(baseCabinetInfo);
    }

    /**
     * 新增电柜信息
     * 
     * @param baseCabinetInfo 电柜信息
     * @return 结果
     */
    @Override
    public int insertBaseCabinetInfo(BaseCabinetInfo baseCabinetInfo)
    {
        Long cabinetCode = baseCabinetInfo.getCabinetCode();
        BaseCabinetInfo saveBaseCabinet = new BaseCabinetInfo();
        saveBaseCabinet.setCabinetCode(cabinetCode);
        List<BaseCabinetInfo> baseCabinetInfoList = baseCabinetInfoMapper.selectBaseCabinetInfoList(saveBaseCabinet);
        if (!baseCabinetInfoList.isEmpty()){
            throw new RuntimeException("该电柜编号已存在,请重新输入");
        }

        return baseCabinetInfoMapper.insertBaseCabinetInfo(baseCabinetInfo);
    }

    /**
     * 修改电柜信息
     * 
     * @param baseCabinetInfo 电柜信息
     * @return 结果
     */
    @Override
    public int updateBaseCabinetInfo(BaseCabinetInfo baseCabinetInfo)
    {
        Long cabinetCode = baseCabinetInfo.getCabinetCode();
        BaseCabinetInfo saveBaseCabinet = new BaseCabinetInfo();
        saveBaseCabinet.setCabinetCode(cabinetCode);
        List<BaseCabinetInfo> baseCabinetInfoList = baseCabinetInfoMapper.selectBaseCabinetInfoList(saveBaseCabinet);
        if (!baseCabinetInfoList.isEmpty()
                && !baseCabinetInfo.getObjId().equals(baseCabinetInfoList.get(0).getObjId())){
            throw new RuntimeException("该电柜编号已存在,请重新输入");
        }
        return baseCabinetInfoMapper.updateBaseCabinetInfo(baseCabinetInfo);
    }

    /**
     * 批量删除电柜信息
     * 
     * @param objIds 需要删除的电柜信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseCabinetInfoByObjIds(Long[] objIds)
    {
        return baseCabinetInfoMapper.deleteBaseCabinetInfoByObjIds(objIds);
    }

    /**
     * 删除电柜信息信息
     * 
     * @param objId 电柜信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseCabinetInfoByObjId(Long objId)
    {
        return baseCabinetInfoMapper.deleteBaseCabinetInfoByObjId(objId);
    }
}
